package WebGUI::i18n::Spanish::Macro_LastModified;
use utf8;
our $I18N = {
  'Unknown' => {
    'lastUpdated' => '1302873025',
    'message' => 'Desconocido'
  },
  'never' => {
    'lastUpdated' => '1224120232',
    'message' => 'Nunca'
  }
}
;

1;
